pub struct EmbeddedPicture {
pub mime: String,
pub picture_type: PictureType,
pub description: String,
pub width: u32,
pub height: u32,
pub data: Vec<u8>,
}Expand description
An embedded picture extracted from a backing file at scan time (a FLAC PICTURE block or an MP3 APIC frame), before it is content-addressed and stored.
Fields
mime: Stringpicture_type: PictureTypedescription: Stringwidth: u32height: u32data: Vec<u8>Trait Implementations
Sourceimpl Clone for EmbeddedPicture
impl Clone for EmbeddedPicture
Sourcefn clone(&self) -> EmbeddedPicture
fn clone(&self) -> EmbeddedPicture
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmbeddedPicture
impl Debug for EmbeddedPicture
impl Eq for EmbeddedPicture
Sourceimpl PartialEq for EmbeddedPicture
impl PartialEq for EmbeddedPicture
Sourcefn eq(&self, other: &EmbeddedPicture) -> bool
fn eq(&self, other: &EmbeddedPicture) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EmbeddedPicture